<?php
if (!defined('ABSPATH')) {
    exit;
}

function api_post_grid_get_posts(WP_REST_Request $request)
{
    $term_id = $request->get_param('term_id');
    $category = $request->get_param('category');

    if (empty($term_id) && !empty($category)) {
        $term_id = $category;
    }
    $taxonomy = $request->get_param('taxonomy');
    $post_type = $request->get_param('post_type');
    $per_page = $request->get_param('per_page');
    $page = $request->get_param('page');
    $order = $request->get_param('order');
    $orderby = $request->get_param('orderby');

    $args = [
        'post_type' => $post_type,
        'posts_per_page' => $per_page,
        'paged' => $page,
        'order' => $order,
        'orderby' => $orderby,
        'post_status' => 'publish',
    ];


    if ($term_id) {
        if ($post_type === 'post') {
            $args['category_name'] = $term_id;
        } elseif ($taxonomy) {
            $field_type = is_numeric($term_id) ? 'term_id' : 'slug';
            $args['tax_query'] = [
                [
                    'taxonomy' => $taxonomy,
                    'field' => $field_type,
                    'terms' => $term_id,
                ],
            ];
        }
    }

    $query = new WP_Query($args);

    $posts = [];
    if ($query->have_posts()) {
        while ($query->have_posts()) {
            $query->the_post();
            $featured_image = get_the_post_thumbnail_url(get_the_ID(), 'medium');

            $posts[] = [
                'id' => get_the_ID(),
                'title' => get_the_title(),
                'link' => get_permalink(),
                'image' => $featured_image ? $featured_image : 'default-image.jpg',
            ];
        }
    }

    wp_reset_postdata();

    $response = [
        'total_posts' => $query->found_posts,
        'posts' => $posts,
    ];

    return rest_ensure_response($response);
}